# =========================================================================== #
# Gemspec for Project Dictionaries.
# =========================================================================== #
require 'roebe'
require 'dictionaries/version/version.rb'

Gem::Specification.new { |s|

  s.name    = 'dictionaries'
  s.version = Dictionaries::VERSION
  s.date    = Time.now.strftime('%Y-%m-%d')

  DESCRIPTION = <<-EOF

This project is called dictionaries.

It used to be called ask_english_words but the name was changed towards
"dictionaries", when the focus became on dictionaries in general rather
than merely translations from and to the english language.

There are a total of #{Dictionaries.n_entries?} english words
registered, with the associated german translation. (It is
german primarily because that is my native language, but in
principle this project could be extended to include other
languages as well. You only need to add a yaml file containing
the key-value pairs.)

If you need a more comprehensive dictionary, I can recommend
the file de-en.txt that is part of the tu-chemnitz 
distribution ( https://www-user.tu-chemnitz.de/~fri/ding/ ). That
file is really huge - about 20 MB.

In principle, the dictionaries project could be extended to 
make use of that massive file instead. I will be thinking
about this for the time being (starting at July 2018).

  EOF

  s.summary     = DESCRIPTION
  s.description = DESCRIPTION

  # ========================================================================= #
  # Show this message when a user installs this project.
  # ========================================================================= #
  s.post_install_message = <<-EOF

  This project can ask or translate english or italian words (or words
  from any other language, as long as a .yml file is supplied that
  contains these key-value pair entries).

  This project is probably not very useful for other people, but it helps
  me to improve my knowledge about the english or italian language or
  any other language.

  For more information, have a look at the main README.md file, which
  can also be found on the hompage of this gem at rubygems.org, on
  the bottom right side (see https://www.rubydoc.info/gems/dictionaries/ ).

  EOF
  
  s.extra_rdoc_files = %w()

  s.authors  = ['Robert A. Heiler']
  s.email    = Roebe.email?
  s.files    = Dir['**/*']
  # s.files   << 'README.md'
  # s.files   << 'USAGE.md'
  s.license  = 'MIT'
  s.homepage = 'https://www.rubydoc.info/gems/dictionaries/'

  s.required_ruby_version     = '>= '+Roebe.third_most_stable_version_of_ruby
  s.required_rubygems_version = '>= '+Gem::VERSION
  s.rubygems_version          = '>= '+Gem::VERSION

  # ========================================================================= #
  # External dependencies for the project:
  # ========================================================================= #
  s.add_dependency 'colours'
  s.add_dependency 'generate_shell_completion'
  s.add_dependency 'opn'
  s.add_dependency 'open'
  s.add_dependency 'save_file'
  s.add_dependency 'xorg_buffer'

}